@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20210226';
+our $VERSION = '0.20210331';
 
-# Table last modified: 2021-02-26
+# Table last modified: 2021-03-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,10 +63,10 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|2[0-57-9]|6[16-8]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|7[06]|2[015]|9[15-7]|0[35-7])|406))',
+    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|2[0-57-9]|6[16-8]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[15-7]|0[35-7])|406))',
     '061' => '(?:(?:1(?:49[236-8]|39[2356]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68]|5[56])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
-    '063' => '(?:8(?:5(?:22|58|0[17]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
+    '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
     '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[035-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
@@ -108,19 +108,19 @@ our %ZIP_TABLE = (
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|9[0-4]|7[0-25-8]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-579])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|2[0146]|4[05]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|5[158]|1[014-8]|8[1389]|4[25]|3[0-589]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|3[02358]|4[0-5]|0[1-79])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|4[03489]|0[124-8]|8[168]|2[0-4679]|5[0156]|6[08]|1[05689])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-35]|6[014589]|5[1-36-8]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9]|8[2-68])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|2[0136]|8[015689]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:20|39|55|0[1258]|7[07]|8[58]|1[01])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6050))',
+    '105' => '(?:(?:8(?:4(?:6[014589]|5[1-36-8]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9]|8[2-68])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|2[0136]|8[015689]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:20|39|55|0[1258]|7[07]|8[58]|1[01])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6050))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|7[278]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|7[23589]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|3[029]|1[014-7]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:2[0-2568]|6[0259]|5[34]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|1[1246]|3[0138]|0[1-35689]|5[015-8]|2[48]|8[035])|7(?:[15]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|1[1246]|3[0138]|0[1-35689]|5[015-8]|2[48]|8[035])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|6[0-3]|3[38]|5[04-8]|8[16]|1[0-2]|0[1-48])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|7[147]|4[01356]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-46]|8[014-8]|4[0134689]|0[1-3578]|3[237])|6[12]1))',
-    '120' => '(?:8(?:5(?:44|81|0[17]|7[057]|1[02]|2[068]|3[0469]|5[013-68])|60[12]))',
+    '120' => '(?:8(?:5(?:44|81|5[014-68]|0[17]|1[02]|7[05]|2[068]|3[0469])|60[12]))',
     '121' => '(?:8(?:5(?:77|1[025]|0[458]|8[58]|5[05]|2[01])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
     '123' => '(?:85(?:40|88|1[1247]|0[135-9]))',
     '124' => '(?:85(?:60|77|2[04]|3[03589]|0[1-39]|8[58]|5[05]|1[01]))',
@@ -336,7 +336,7 @@ our %ZIP_TABLE = (
     '360' => '(?:(?:8(?:5(?:[67]7|32|43|2[0-3]|1[25]|8[05]|0[12]|5[589])|6(?:11|20|0[18]))|019[2-7]))',
     '361' => '(?:8(?:5(?:[58]5|39|1[013]|0[3-8])|60[1-4]))',
     '362' => '(?:8(?:5(?:[67]7|42|0[148]|3[19]|2[013]|8[58]|5[035]|1[017])|688))',
-    '363' => '(?:8(?:5(?:10|0[19]|5[58])|601))',
+    '363' => '(?:8(?:5(?:10|0[159]|5[58])|601))',
     '364' => '(?:8(?:5(?:[01]1|[58]5)|633))',
     '365' => '(?:8(?:5(?:[58]5|1[24]|0[1-3568])|60[13]))',
     '366' => '(?:85(?:67|81|1[015]|0[12]))',
@@ -363,7 +363,7 @@ our %ZIP_TABLE = (
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
     '388' => '(?:85(?:11|22|55))',
     '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
-    '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|4[013]|1[0158]|3[01359]|[56][05]|2[035])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
+    '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|4[013]|1[0158]|3[01359]|[56][05]|2[035])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:65|0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
     '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[0167]|1[0-2]|8[08]|2[15])|0(?:29[2-7]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
     '393' => '(?:8(?:5(?:[58]5|11|0[1-3])|601))',
@@ -413,7 +413,7 @@ our %ZIP_TABLE = (
     '439' => '(?:865[01])',
     '440' => '(?:8(?:5(?:43|0[124-8]|3[013]|[12][0-8])|60[134]))',
     '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|4[05]|8[08]|0[1-37]|1[0-2579]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
-    '442' => '(?:8(?:5(?:20|58|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|7[35-7]|8[015-8]|9[01]|4[013-6])|60[1-3]))',
+    '442' => '(?:8(?:5(?:20|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|5[58]|7[35-7]|8[015-8]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:[05]5|88)|6[01]1)|019[2-4]))',
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
@@ -529,8 +529,8 @@ our %ZIP_TABLE = (
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|0[1245]|5[18])|729))',
     '560' => '(?:85(?:79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
-    '561' => '(?:85(?:[06]1|20|77|5[058]|1[01]))',
-    '562' => '(?:8(?:5(?:11|22|43|8[0568]|[05][58]|6[0278])|686))',
+    '561' => '(?:85(?:01|20|77|5[058]|1[01]))',
+    '562' => '(?:8(?:5(?:11|22|43|55|8[0568]|0[58]|6[0278])|6(?:78|86)))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
     '564' => '(?:8(?:5(?:23|5[015]|0[13]|6[57]|1[15])|6(?:80|5[01])))',
     '565' => '(?:85(?:11|40|65))',
@@ -538,7 +538,7 @@ our %ZIP_TABLE = (
     '567' => '(?:8(?:5(?:[34]0|[56]7|1[015]|2[0135]|8[58]|7[08]|0[1257])|6(?:51|80)))',
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)))',
-    '571' => '(?:8(?:5(?:[45]5|67|71|8[05]|0[2-47])|6(?:33|40|86)))',
+    '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:33|40|86)))',
     '572' => '(?:85(?:40|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
     '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[01])|666)|10(?:[34]0|1[03]|0[1478])|019[356]))',
     '574' => '(?:85(?:[58]5|01|3[014]))',
@@ -550,7 +550,7 @@ our %ZIP_TABLE = (
     '580' => '(?:8(?:50[1-5]|601))',
     '581' => '(?:8(?:5(?:[08]5|11|39|58)|686))',
     '582' => '(?:85(?:01|55|8[25]))',
-    '583' => '(?:85(?:01|22|63|8[0358]|3[34]|5[058]))',
+    '583' => '(?:85(?:01|22|63|3[3-5]|8[0358]|5[058]))',
     '584' => '(?:8(?:5(?:[13]1|22|40|85)|651))',
     '585' => '(?:85(?:01|85|5[05]))',
     '586' => '(?:85(?:[01]1|[58]5|77|2[18]))',
@@ -598,7 +598,7 @@ our %ZIP_TABLE = (
     '632' => '(?:(?:8(?:5(?:[14]0|[67]7|8[578]|5[258])|6(?:79|88))|0292))',
     '633' => '(?:(?:8(?:5(?:01|38|85)|686)|0(?:29[28]|39[28])|2[14]92))',
     '634' => '(?:85(?:5[015]|2[1-4]|8[056]|0[1-35-7]|1[01]|6[017]))',
-    '635' => '(?:8(?:5(?:30|85|0[128]|2[08]|1[15])|787))',
+    '635' => '(?:8(?:5(?:30|85|0[12]|2[08]|1[15])|787))',
     '636' => '(?:(?:0(?:29[2-58]|19[238]|39[238])|8(?:5(?:[358]5|11|0[13])|798)))',
     '637' => '(?:85[01]1)',
     '638' => '(?:(?:85(?:[0256]1|10)|0[23]92))',
@@ -758,7 +758,7 @@ our %ZIP_TABLE = (
     '797' => '(?:(?:(?:02|1[257])92|85[01]1))',
     '798' => '(?:(?:8(?:6(?:01|1[14])|51[01])|4(?:19[2-7]|292|495)|1(?:39[2357]|192)|3(?:39[23]|792)|2192))',
     '799' => '(?:(?:1(?:5(?:8[128]|9[2-68])|39[2-5]|198|692)|2(?:29[2-4]|49[236]|19[25]|39[23]|69[26])|0(?:19[2-7]|49[235-8])|3(?:19[2-68]|79[23]|292)))',
-    '800' => '(?:(?:0(?:2(?:9[3-8]|8[1-68])|39[2-6])|8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))))',
+    '800' => '(?:(?:0(?:2(?:9[3-8]|8[12568])|39[2-6])|8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))))',
     '801' => '(?:8(?:5(?:85|5[05]|0[237]|1[01])|601))',
     '802' => '(?:8(?:5(?:33|8[015]|1[0-257]|0[1278]|5[058]|2[1249]|6[0167]|4[035]|7[017])|6(?:42|51|77|86|0[14])|701))',
     '803' => '(?:8(?:5(?:20|43|3[0-35]|1[0-37]|6[17]|5[058]|8[068]|0[1458])|6(?:02|30|86|6[06])|787))',
@@ -766,18 +766,18 @@ our %ZIP_TABLE = (
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
     '806' => '(?:8(?:5(?:67|70|4[03]|0[19]|5[58]|1[01]|8[56])|6(?:[68]6|12|79)))',
     '807' => '(?:(?:85(?:01|8[568]|5[56])|019[28]|1392))',
-    '808' => '(?:(?:8(?:5(?:1[045]|0[25]|5[058]|8[58])|606)|0196))',
+    '808' => '(?:(?:8(?:5(?:1[045]|5[058]|8[58]|0[125])|606)|0196))',
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|4[28]|6[02-79]|7[035-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6]|3[1346-9])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[258]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
     '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|4[0-68]|2[0-24-689]|7[025-8]|5[0-79]|1[0-8]|6[0-25689])|5(?:[23578]\d|0[1-9]|6[0-689]|[14][0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
-    '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:2[36]|8[01])))',
+    '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:77|0[135]|2[025]|6[57]|8[589]|1[0-2]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
     '816' => '(?:8(?:5(?:[67]7|01|30|[58][05]|1[01])|666))',
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
     '818' => '(?:(?:8(?:5(?:16|55|67|0[1-3]|7[178]|4[09]|8[58])|6(?:42|86|6[68]))|019[2-578]))',
-    '819' => '(?:(?:85(?:11|33|85|5[0-258]|0[124])|1(?:19[235]|[36]92)|0(?:19[23]|395)))',
+    '819' => '(?:(?:8(?:5(?:11|33|85|5[0-258]|0[124])|611)|1(?:19[235]|[36]92)|0(?:19[23]|395)))',
     '820' => '(?:(?:8(?:5(?:[24]0|33|1[02367]|5[05]|0[125-8])|60[1-357])|0(?:[2357]92|69[36])|119[23]))',
     '821' => '(?:8501)',
     '822' => '(?:(?:1(?:29[236]|19[23]|492)|8(?:5(?:[58]5|01)|666)))',
@@ -916,7 +916,7 @@ our %ZIP_TABLE = (
     '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01)|701)|0(?:19[235-7]|293)))',
     '958' => '(?:(?:8(?:5(?:01|33|85|5[58])|6(?:01|86))|0292))',
     '959' => '(?:(?:0(?:29[2-6]|59[235-7]|19[2-4]|39[23]|492)|1(?:29[2-468]|39[2357]|69[235]|79[457])|2(?:6(?:88|93)|39[357]|09[23]|292|711)|3(?:19[2-46]|49[23]|292|993)|4(?:49[57]|392)))',
-    '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|1[1-358])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
+    '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|1[1-3568])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
     '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
